import { Entity } from './types';
import { AnyAction } from 'redux';
/**
 * Hardcoded initial state for the Redux store concerned with pending REST async operations, the set of entities in <namespace>, and a selected entity.
 * @memberof RESTReduxCRUD
 * @typedef {object} defaultState
 * @property {boolean} defaultState.listPending=false True when a list request is pending. False otherwise.
 * @property {boolean} defaultState.getPending=false True when a get request is pending. False otherwise.
 * @property {boolean} defaultState.addPending=false True when an add request is pending. False otherwise.
 * @property {array} defaultState.pendingEdits="[]" The list of entities being edited.
 * @property {boolean} defaultState.deletePending=false True when a delete request is pending. False otherwise.
 * @property {array} defaultState.entities="[]" The list of entities in state.
 */
export declare const defaultState: {
    listPending: boolean;
    addPending: boolean;
    pendingEdits: any[];
    deletePending: boolean;
    entities: any[];
};
/**
 * Reduces namespaced actions to changes in state. In each reducer a new state object is constructed and returned with specific portions updated according to what action the reducer is written for.
 * @memberof RESTReduxCRUD
 * @namespace
 * @param {string} namespace The namespace of our actionTypes.
 */
declare const reducers: <T extends Entity>(namespace: string) => (state: Readonly<{
    entities: ReadonlyArray<T>;
    pendingEdits: ReadonlyArray<T>;
    listPending: boolean;
    deletePending: boolean;
    addPending: boolean;
}>, action: AnyAction) => Readonly<{
    entities: ReadonlyArray<T>;
    pendingEdits: ReadonlyArray<T>;
    listPending: boolean;
    deletePending: boolean;
    addPending: boolean;
}>;
export default reducers;
